API reference
=============

The reference below is generated from the public Python API. Functions and classes inherit docstrings directly from the source code to keep behavior descriptions synchronized.

.. autosummary::
   :toctree: api/
   :caption: Core modules
   :recursive:

   parcellate
   parcellate.parcellation.volume
   parcellate.metrics.base
   parcellate.metrics.volume
   parcellate.utils.image
